@@ -303,7 +303,7 @@ class Model(_AbstractRateModel, BaseModel):
         function: Callable[..., float],
         stoichiometry: Dict[str, float],
         args: List[str],
-        reversible: bool = False,
+        reversible: bool | None = None,
     ) -> None:
         modifiers = []
         parameters = []
@@ -319,6 +319,12 @@ class Model(_AbstractRateModel, BaseModel):
         substrates = [k for k, v in stoichiometry.items() if v < 0]
         products = [k for k, v in stoichiometry.items() if v > 0]
 
+        if reversible is None:
+            if any(i in dynamic_variables for i in products):
+                reversible = True
+            else:
+                reversible = False
+
         self.add_rate(
             rate_name=rate_name,
             function=function,
@@ -484,36 +490,6 @@ class Model(_AbstractRateModel, BaseModel):
             return {k: ones * v for k, v in self._get_fluxes(fcd=fcd).items()}  # type: ignore
         return {k: ones * v for k, v in self._get_fluxes_array(fcd=fcd).items()}  # type: ignore
 
-    def get_fluxes_array(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> Array:
-        """Calculate the fluxes at time point(s) t."""
-        return np.array(list(self.get_fluxes_dict(y=y, t=t).values())).T
-
-    def get_fluxes_df(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> pd.DataFrame:
-        """Calculate the fluxes at time point(s) t."""
-        if isinstance(t, (int, float)):
-            t = [t]  # type: ignore
-        return pd.DataFrame(data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names())
-
     # This can't get keyword-only arguments, as the integrators are calling it with
     # positional arguments
     def _get_rhs(self, t: Union[float, ArrayLike, Array], y: List[Array]) -> Array:
@@ -534,25 +510,6 @@ class Model(_AbstractRateModel, BaseModel):
                 dxdt[k] += n * fluxes[flux]
         return np.array([dxdt[i] for i in compounds_local], dtype="float")
 
-    def get_right_hand_side(
-        self,
-        y: Union[
-            Dict[str, float],
-            Dict[str, ArrayLike],
-            Dict[str, Array],
-            Array,
-            ArrayLike,
-        ],
-        t: Union[float, ArrayLike, Array] = 0.0,
-    ) -> Dict[str, float]:
-        """Calculate the right hand side of the ODE system."""
-        self._update_derived_parameters()
-        fcd = self.get_full_concentration_dict(y=y, t=t)  # type: ignore
-        fcd_array = [fcd[i] for i in self.get_compounds()]
-        rhs = self._get_rhs(t=t, y=fcd_array)
-        eqs = [f"d{cpd}dt" for cpd in self.get_compounds()]
-        return dict(zip(eqs, rhs))
-
     ##########################################################################
     # Model conversion functions
     ##########################################################################
